@@ -116,7 +116,7 @@ pointsXYZ_plot <- function(data, center=id.SO3, column=1) {
 #This is a modified rgl.sphgrid that I use to create interactive plots
 rgl.sphgrid2<-function (radius = 1, col.long = "red", col.lat = "blue", deggap = 15, 
                         longtype = "H", add = FALSE) {
-  if (add == F) {
+  if (add == FALSE) {
     open3d()
   }
   for (lat in seq(-90, 90, by = deggap)) {
@@ -126,8 +126,8 @@ rgl.sphgrid2<-function (radius = 1, col.long = "red", col.lat = "blue", deggap =
     else {
       col.grid = "grey"
     }
-    plot3d(sph2car(long = seq(0, 360, len = 100), lat = lat, 
-                   radius = radius, deg = T), col = col.grid, add = T, 
+    plot3d(sphereplot::sph2car(long = seq(0, 360, len = 100), lat = lat, 
+                   radius = radius, deg = TRUE), col = col.grid, add = TRUE, 
            type = "l")
   }
   for (long in seq(0, 360 - deggap, by = deggap)) {
@@ -137,8 +137,8 @@ rgl.sphgrid2<-function (radius = 1, col.long = "red", col.lat = "blue", deggap =
     else {
       col.grid = "grey"
     }
-    plot3d(sph2car(long = long, lat = seq(-90, 90, len = 100), 
-                   radius = radius, deg = T), col = col.grid, add = T, 
+    plot3d(sphereplot::sph2car(long = long, lat = seq(-90, 90, len = 100), 
+                   radius = radius, deg = TRUE), col = col.grid, add = TRUE, 
            type = "l")
   }
   if (longtype == "H") {
@@ -172,7 +172,6 @@ rgl.sphgrid2<-function (radius = 1, col.long = "red", col.lat = "blue", deggap =
 #' @param m number of bootstrap replicates to use in bootstrap confidence regions.
 #' @param interactive logical; if \code{TRUE} \code{sphereplot} is used to create an interactive 3D plot, otherwise \code{\link{ggplot2}} is used
 #' @param ... parameters passed onto the points layer.
-#' @note The option \code{interactive=TRUE} requires the \code{sphereplot} package.  If \code{sphereplot} is not available then the static plot is created.
 #' @return  A visualization of rotation data.
 #' @aliases plot.Q4
 #' @S3method plot SO3
@@ -195,19 +194,9 @@ rgl.sphgrid2<-function (radius = 1, col.long = "red", col.lat = "blue", deggap =
 plot.SO3 <- function(x, center=mean(x), col=1, to_range=FALSE, show_estimates=NULL, label_points=NULL, mean_regions=NULL, median_regions=NULL, alp=NULL, m=300, interactive=FALSE,  ...) {
   
   if(interactive){
-    
-    reqSph<-suppressWarnings(require(sphereplot))
-    
-    if(reqSph){
       
-      col<-col[1]   #For interactive plots only one column can be displayed at a time
+    col<-col[1]   #For interactive plots only one column can be displayed at a time
       
-    }else{
-      
-      warning("The package sphereplot is required for interactive plots, a static plot will be returned.")
-      interactive<-FALSE
-      
-    }
   }
   
   if(length(col)>1){
@@ -372,16 +361,16 @@ plot.SO3 <- function(x, center=mean(x), col=1, to_range=FALSE, show_estimates=NU
   if(interactive){
     #require(sphereplot)
     rgl.sphgrid2(deggap=22.5)
-    pts <- car2sph(proj2d)
-    rgl.sphpoints(pts,deg=T,size=4)
+    pts <- sphereplot::car2sph(proj2d)
+    sphereplot::rgl.sphpoints(pts,deg=TRUE,size=4)
     
     if(!is.null(estDF)||!is.null(meanregDF)||!is.null(medianregDF))
       plot.new()
     
     if(!is.null(estDF)){
-      estpts <- car2sph(estDF[,-4])
+      estpts <- sphereplot::car2sph(estDF[,-4])
       
-      rgl.sphpoints(estpts,deg=T,col=c(2:(nrow(estDF)+1)),size=5)
+      sphereplot::rgl.sphpoints(estpts,deg=TRUE,col=c(2:(nrow(estDF)+1)),size=5)
       
       #Legend
       #text3d(x=1, y=c(.8,1,1.2,1.4)[rmNA], z=1, estDF$lab ,col=c(2:(nrow(estDF)+1)))
@@ -390,7 +379,7 @@ plot.SO3 <- function(x, center=mean(x), col=1, to_range=FALSE, show_estimates=NU
     
     if(!is.null(label_points)){
       label_points<-c(label_points,rep("",nrow(pts)-length(label_points)))
-      rgl.sphtext(pts,text=label_points)
+      sphereplot::rgl.sphtext(pts,text=label_points)
     }
     
     numRegs<-0
@@ -398,9 +387,9 @@ plot.SO3 <- function(x, center=mean(x), col=1, to_range=FALSE, show_estimates=NU
     if(!is.null(meanregDF)||!is.null(medianregDF)){
       regDF<-rbind(meanregDF,medianregDF)
       
-      regpts <- car2sph(regDF)
+      regpts <- sphereplot::car2sph(regDF)
       numRegs<-nrow(regpts)/500
-      rgl.sphpoints(regpts,deg=T,col=rep((1:numRegs)+1,each=500))
+      sphereplot::rgl.sphpoints(regpts,deg=TRUE,col=rep((1:numRegs)+1,each=500))
       
       #Confidence region legend
       legend('topright',c(as.character(Regions$Meth2),as.character(MedRegions$Meth)),
@@ -411,7 +400,7 @@ plot.SO3 <- function(x, center=mean(x), col=1, to_range=FALSE, show_estimates=NU
     #if(!is.null(medianregDF)){
     #  medregpts <- car2sph(medianregDF)
     #  numRegs2<-nrow(MedRegions)
-    #  rgl.sphpoints(medregpts,deg=T,col=rep((1:numRegs2)+1+numRegs,each=500))
+    #  rgl.sphpoints(medregpts,deg=TRUE,col=rep((1:numRegs2)+1+numRegs,each=500))
       
     #  legend(.66,1,MedRegions$Meth,col=c((1:numRegs2)+1+numRegs),lty=19,title='Median Regions')
       
@@ -476,21 +465,21 @@ mplotSO3<-function(x, center=mean(x), col=1, to_range=FALSE, show_estimates=NULL
   
   ps<-list(p1,p2,p3,p4)
   ps<-!sapply(ps, is.null)
-  if(all(ps==c(T,T,T,T))){
+  if(all(ps==c(TRUE,TRUE,TRUE,TRUE))){
     gridExtra::grid.arrange(p1,p2,p3,p4,nrow=2,widths=c(2,2,2,1))
-  }else if(all(ps==c(T,T,F,T))){
+  }else if(all(ps==c(TRUE,TRUE,FALSE,TRUE))){
     gridExtra::grid.arrange(p1,p2,p4,nrow=1,widths=c(2,2,1))
-  }else if(all(ps==c(T,F,T,T))){
+  }else if(all(ps==c(TRUE,FALSE,TRUE,TRUE))){
     gridExtra::grid.arrange(p1,p3,p4,nrow=1,widths=c(2,2,1))
-  }else if(all(ps==c(F,T,T,T))){
+  }else if(all(ps==c(FALSE,TRUE,TRUE,TRUE))){
     gridExtra::grid.arrange(p2,p3,p4,nrow=1,widths=c(2,2,1))
-  }else if(all(ps==c(T,T,T,F))){
+  }else if(all(ps==c(TRUE,TRUE,TRUE,FALSE))){
     gridExtra::grid.arrange(p1,p2,p3,nrow=1)
-  }else if(all(ps==c(T,T,F,F))){
+  }else if(all(ps==c(TRUE,TRUE,FALSE,FALSE))){
     gridExtra::grid.arrange(p1,p2,nrow=1)
-  }else if(all(ps==c(T,F,T,F))){
+  }else if(all(ps==c(TRUE,FALSE,TRUE,FALSE))){
     gridExtra::grid.arrange(p1,p3,nrow=1)
-  } else if(all(ps==c(F,T,T,F))){
+  } else if(all(ps==c(FALSE,TRUE,TRUE,FALSE))){
     gridExtra::grid.arrange(p2,p3,nrow=1)
   }else{
     stop("Specify the columns correctly.")
